package com.hzya.frame.dingtalk.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.dingtalk.api.DefaultDingTalkClient;
import com.dingtalk.api.DingTalkClient;
import com.dingtalk.api.request.OapiV2DepartmentGetRequest;
import com.dingtalk.api.request.OapiV2UserGetRequest;
import com.dingtalk.api.response.OapiV2DepartmentGetResponse;
import com.dingtalk.api.response.OapiV2UserGetResponse;
import com.hzya.frame.dingtalk.service.IDingTalkService;
import com.hzya.frame.dingtalk.util.DingTalkAccessToken;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * @Description 钉钉service
 * @Author xiangerlin
 * @Date 2024/8/27 16:17
 **/
@Service
public class DingTalkServiceImpl implements IDingTalkService {
    Logger logger = LoggerFactory.getLogger(getClass());
    @Value("${dingtalk.appKey:}")
    private String dAppKey;
    @Value("${dingtalk.appSecret:}")
    private String dAppSecret;


    /**
     * 根据userid获取用户详情
     *
     * @param userId    钉钉userid
     * @param appKey
     * @param appSecret
     * @return
     */
    @Override
    public OapiV2UserGetResponse.UserGetResponse getUserById(String userId, String appKey, String appSecret) {
        DingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/topapi/v2/user/get");
        OapiV2UserGetRequest req = new OapiV2UserGetRequest();
        req.setUserid(userId);
        req.setLanguage("zh_CN");
        try {
            OapiV2UserGetResponse rsp = client.execute(req, DingTalkAccessToken.getAccessToken(appKey,appSecret));
            if (rsp.isSuccess()){
                OapiV2UserGetResponse.UserGetResponse result = rsp.getResult();
                String s = JSONObject.toJSONString(result);
                logger.info("人员详情信息:{}",s);
                return result;
            }
        }catch (Exception e){
            logger.error("根据部门id获取钉钉用户详情出错：{}",e);
        }
        return null;
    }

    /**
     * 根据userid获取用户详情
     *
     * @param userId
     * @return
     */
    @Override
    public OapiV2UserGetResponse.UserGetResponse getUserById(String userId) {
        return getUserById(userId,dAppKey,dAppSecret);
    }


    /**
     * 根据部门id获取部门详情
     *
     * @param deptId    钉钉部门id
     * @param appKey
     * @param appSecret
     * @return
     */
    @Override
    public OapiV2DepartmentGetResponse.DeptGetResponse getDeptById(Long deptId, String appKey, String appSecret) {
        DingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/topapi/v2/department/get");
        OapiV2DepartmentGetRequest req = new OapiV2DepartmentGetRequest();
        req.setDeptId(deptId);
        req.setLanguage("zh_CN");
        try {
            OapiV2DepartmentGetResponse rsp = client.execute(req, DingTalkAccessToken.getAccessToken(appKey,appSecret));
            if (rsp.isSuccess()){
                OapiV2DepartmentGetResponse.DeptGetResponse result = rsp.getResult();
                String s = JSONObject.toJSONString(result);
                logger.info("部门详情信息:{}",s);
                return result;
            }
        }catch(Exception e){
            logger.error("根据部门id获取钉钉部门出错：{}",e);
        }
        return null;
    }

    /**
     * 根据部门id获取部门详情
     *
     * @param deptId
     * @return
     */
    @Override
    public OapiV2DepartmentGetResponse.DeptGetResponse getDeptById(Long deptId) {
        return getDeptById(deptId,dAppKey,dAppSecret);
    }

}
